@@ -2,34 +2,29 @@ import os,django
 from django.conf import settings
 # 加载django配置
 current_dir=os.getcwd()
-setting_model_str=current_dir.split("\\")[-1]+".settings"
+if "/" in current_dir:
+    setting_model_str=current_dir.split("/")[-1]+".settings"
+else:
+    setting_model_str=current_dir.split("\\")[-1]+".settings"
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", setting_model_str)
 django.setup()
 # your imports, e.g. Django models
 from c_mssql import DB_Config
 from c_mssql.mssql_conn import Mssql_Conn
 
-import io,json,os
-
-
-
-
-def add_sql_description(table_name,description,column_name=None):
-    table_str="INNER JOIN sys.columns AS c ON t.object_id = c.object_id" if bool(column_name) else ""
-    join_str=" AND ep.minor_id = c.column_id " if bool(column_name) else " and ep.minor_id=0 "
-    where_str=f"AND C.name= '{column_name}'" if bool(column_name) else ""
-    update_str=f""",@level2type = N'Column', @level2name = '{column_name}'""" if bool(column_name) else ""
 
+def add_sql_description(table_name,column_name,description):
     sql_str=f"""
 IF EXISTS(
 SELECT top 1 1
 FROM sys.tables AS t
-{table_str}
+INNER JOIN sys.columns
+AS c ON t.object_id = c.object_id
 inner JOIN sys.extended_properties AS ep
-ON ep.major_id = t.object_id  {join_str} and ep.class =1
+ON ep.major_id = c.object_id AND ep.minor_id = c.column_id and ep.class =1
 WHERE 1=1
 AND t.name='{table_name}' 
-{where_str}
+AND C.name= '{column_name}'
 AND EP.class=1
 )
 BEGIN
@@ -37,8 +32,8 @@ EXEC sp_updateextendedproperty
 @name = N'MS_Description',   
 @value = '{description}',  
 @level0type = N'Schema', @level0name = 'dbo',  
-@level1type = N'Table',  @level1name = '{table_name}'  
-{update_str};
+@level1type = N'Table',  @level1name = '{table_name}',  
+@level2type = N'Column', @level2name = '{column_name}'; 
 END
 ELSE
 BEGIN
@@ -46,12 +41,11 @@ EXEC sp_addextendedproperty
 @name = N'MS_Description',   
 @value = '{description}',  
 @level0type = N'Schema', @level0name = 'dbo',  
-@level1type = N'Table',  @level1name = '{table_name}'
-{update_str};
+@level1type = N'Table',  @level1name = '{table_name}',  
+@level2type = N'Column', @level2name = '{column_name}'; 
 END
  
 """
-    # print(sql_str)
     server=settings.DATABASES["default"]["HOST"]
     database=settings.DATABASES["default"]["NAME"]
     username=settings.DATABASES["default"]["USER"]
@@ -63,17 +57,15 @@ END
     conn.close()
 
 
-def update_MS_Description(models,modelname="project.models"):
+def update_MS_Description(models):
     data_list=[]
     for key in dir(models):
         model=getattr(models,key)
         try:
-            if model.__module__==modelname:
+            if model.__module__=="project.models":
                 model_name=key
                 model=model
-                table_name=model._meta.db_table
-                row_dict={"table_name":model._meta.db_table,"field_name":None,"verbose_name":model._meta.verbose_name}
-                data_list.append(row_dict)
+                table_name=model.__dict__["_meta"].db_table
                 filed_str=model.__doc__
                 filed_str=filed_str[len(model_name)+1:len(filed_str)-1]
                 for field in filed_str.split(","):
@@ -90,6 +82,6 @@ def update_MS_Description(models,modelname="project.models"):
 
     for row_dict in data_list:
         print("正在更新:",row_dict)
-        add_sql_description(row_dict["table_name"],row_dict["verbose_name"],row_dict["field_name"])
+        add_sql_description(row_dict["table_name"],row_dict["field_name"],row_dict["verbose_name"])
     print("更新成功")
-    
+    
\ No newline at end of file
