@@ -2,10 +2,13 @@ from setuptools import setup, find_packages
 
 # with open("tencent_message\README.md", "r",encoding="utf-8") as fh:
 #     long_description = fh.read()
-long_description="根据django 的 model 自动生成sqlserver的列说明\n0.1.2增加了表说明 "
+long_description="""
+0.1.1根据django 的 model 自动生成sqlserver的列说明\n
+0.1.2增加了数据表的说明\n
+0.1.3修复了Linux的路径错误"""
 setup(  
     name = 'django_to_sqlserver_description',  
-    version = '0.1.2',
+    version = '0.1.3',
     # keywords = ('chinesename',),  
     description = '根据django 的 model 自动生成sqlserver的列说明',  
     long_description=long_description,
